@@ -32,8 +32,8 @@
 
 #include "qof.h"
 
-/* Note that we keep the keys for this hash table in a GCache
- * (qof_util_string_cache), as it is very likely we will see the
+/* Note that we keep the keys for this hash table in the
+ * qof_string_cache, as it is very likely we will see the
  * same keys over and over again  */
 
 struct _KvpFrame
@@ -108,7 +108,7 @@ kvp_frame_new(void)
 static void
 kvp_frame_delete_worker(gpointer key, gpointer value, gpointer user_data)
 {
-    qof_util_string_cache_remove(key);
+    qof_string_cache_remove(key);
     kvp_value_delete((KvpValue *)value);
 }
 
@@ -143,7 +143,7 @@ kvp_frame_copy_worker(gpointer key, gpointer value, gpointer user_data)
 {
     KvpFrame * dest = (KvpFrame *)user_data;
     g_hash_table_insert(dest->hash,
-                        qof_util_string_cache_insert(key),
+                        qof_string_cache_insert(key),
                         (gpointer)kvp_value_copy(value));
 }
 
@@ -184,7 +184,7 @@ kvp_frame_replace_slot_nc (KvpFrame * frame, const char * slot,
     if (key_exists)
     {
         g_hash_table_remove(frame->hash, slot);
-        qof_util_string_cache_remove(orig_key);
+        qof_string_cache_remove(orig_key);
     }
     else
     {
@@ -194,7 +194,7 @@ kvp_frame_replace_slot_nc (KvpFrame * frame, const char * slot,
     if (new_value)
     {
         g_hash_table_insert(frame->hash,
-                            qof_util_string_cache_insert((gpointer) slot),
+                            qof_string_cache_insert((gpointer) slot),
                             new_value);
     }
 
